#!/bin/bash

# This script creates a lvm snapshot, modify as required
# 
# Input is always:
#  $1 = name of the snapshot, a random name with no spaces or non-printable chars, usually something like "duplicati-0102030011234567"
#  $2 = name of the device to create the snapshot for, this is the output of find-volume.sh, and usually a LVM id like "vg_name/lv_name"
#  $3 = the full path to the temporary folder used by the application, suffixed with a /, eg "/tmp/"
#
# The script MUST output a line with tmpdir="<dir>", where dir is the temporary mounted directory
# This ensures that the script can override the settings to better fit the distro, 
#  and disregard the naming conventions used normally. It also helps if the tools invoked write info
#  to the console that could be misinterpreted as the output path.

# Rename arguments to better symbols
NAME=$1
DEVICE=$2
TMPDIR=$3$NAME

zfs snapshot "$DEVICE@$NAME"
if [ "$?" -ne 0 ]
then
	EXIT_CODE=$?
	echo "Error: zfs snapshot failed: zfs snapshot \"$DEVICE@$NAME\""
	exit $EXIT_CODE
fi

#
# Create a mount point
#
mkdir "$TMPDIR"
if [ "$?" -ne 0 ]
then
	EXIT_CODE=$?
	echo "Error: mkdir \"$TMPDIR\" failed!"
	
	#We have created the volume, so remove it before exit
	zfs destroy "$DEVICE@$NAME"
	exit $EXIT_CODE
fi

MOUNT_OPTIONS="ro"

#
# Mount the snapshot on the mount point
#
mount -o "$MOUNT_OPTIONS" -t zfs "$DEVICE@$NAME" "$TMPDIR"
if [ "$?" -ne 0 ]
then
	EXIT_CODE=$?
	echo "Error: mount -o \"$MOUNT_OPTIONS\" -t zfs \"$DEVICE@$NAME\" \"$TMPDIR\" failed!"

	#We have created the volume, so remove it before exit
	zfs destroy "$DEVICE@$NAME"
	rmdir $TMPDIR
	exit $EXIT_CODE
fi

#
# Report back to the caller what the name of the snapshot volume is
#
echo "tmpdir=\"$TMPDIR\""
exit 0
